@@ -1,8 +1,4 @@
-//
-// Sysinfo
-//
-// Copyright (c) 2015 Guillaume Gomez
-//
+// Take a look at the license at the top of the repository in the LICENSE file.
 
 mod component;
 mod disk;
@@ -14,6 +10,7 @@ mod processor;
 mod system;
 mod tools;
 mod users;
+mod utils;
 
 pub use self::component::Component;
 pub use self::disk::Disk;
