@@ -1,8 +1,4 @@
-//
-// Sysinfo
-//
-// Copyright (c) 2018 Guillaume Gomez
-//
+// Take a look at the license at the top of the repository in the LICENSE file.
 
 use sysinfo::ProcessExt;
 use sysinfo::SystemExt;
@@ -45,7 +41,7 @@ fn test_cwd() {
     };
 
     let pid = p.id() as sysinfo::Pid;
-    std::thread::sleep(std::time::Duration::from_millis(250));
+    std::thread::sleep(std::time::Duration::from_secs(1));
     let mut s = sysinfo::System::new();
     s.refresh_processes();
     p.kill().expect("Unable to kill process.");
@@ -81,7 +77,7 @@ fn test_cmd() {
             .spawn()
             .unwrap()
     };
-    std::thread::sleep(std::time::Duration::from_millis(250));
+    std::thread::sleep(std::time::Duration::from_millis(500));
     let mut s = sysinfo::System::new();
     assert!(s.processes().is_empty());
     s.refresh_processes();
@@ -127,7 +123,7 @@ fn test_environ() {
     };
 
     let pid = p.id() as sysinfo::Pid;
-    std::thread::sleep(std::time::Duration::from_millis(250));
+    std::thread::sleep(std::time::Duration::from_secs(1));
     let mut s = sysinfo::System::new();
     s.refresh_processes();
     p.kill().expect("Unable to kill process.");
@@ -171,6 +167,11 @@ fn test_process_disk_usage() {
     if !sysinfo::System::IS_SUPPORTED || cfg!(feature = "apple-sandbox") {
         return;
     }
+    if std::env::var("FREEBSD_CI").is_ok() {
+        // For an unknown reason, when running this test on Cirrus CI, it fails. It works perfectly
+        // locally though... Dark magic...
+        return;
+    }
 
     fn inner() -> sysinfo::System {
         {
@@ -179,6 +180,8 @@ fn test_process_disk_usage() {
                 .expect("failed to write to file");
         }
         fs::remove_file("test.txt").expect("failed to remove file");
+        // Waiting a bit just in case...
+        std::thread::sleep(std::time::Duration::from_millis(250));
         let mut system = sysinfo::System::new();
         assert!(system.processes().is_empty());
         system.refresh_processes();
@@ -240,3 +243,40 @@ fn cpu_usage_is_not_nan() {
     });
     assert!(checked > 0);
 }
+
+#[test]
+fn test_process_times() {
+    if !sysinfo::System::IS_SUPPORTED || cfg!(feature = "apple-sandbox") {
+        return;
+    }
+    let mut p = if cfg!(target_os = "windows") {
+        std::process::Command::new("waitfor")
+            .arg("/t")
+            .arg("3")
+            .arg("CwdSignal")
+            .stdout(std::process::Stdio::null())
+            .spawn()
+            .unwrap()
+    } else {
+        std::process::Command::new("sleep")
+            .arg("3")
+            .stdout(std::process::Stdio::null())
+            .spawn()
+            .unwrap()
+    };
+
+    let pid = p.id() as sysinfo::Pid;
+    std::thread::sleep(std::time::Duration::from_secs(1));
+    let mut s = sysinfo::System::new();
+    s.refresh_processes();
+    p.kill().expect("Unable to kill process.");
+
+    if let Some(p) = s.process(pid) {
+        assert_eq!(p.pid(), pid);
+        assert!(p.run_time() >= 1);
+        assert!(p.run_time() <= 2);
+        assert!(p.start_time() > p.run_time());
+    } else {
+        panic!("Process not found!");
+    }
+}
